# Metadata Providers

## `override`

Allows for manual hardcoded metadata. This an instance of [`Node`](/doc/jellycommon/struct.Node.html).

Special to this option are the `poster` and `backdrop` properties in the
`private` section. These are reference images local to _library\_path_ and
directly set the counterparts in `public`.

### Example

```yaml
id: library
sources:
  - !override
    public:
      kind: !collection
      title: "My Library"
      children:
        - movies
        - stuff
    private:
      poster: library.png
```

## `auto_children`

Scans the directory of the file currently processed for `*.yaml` and `.jelly`,
parses their ID and adds them as `children`.

## `media`

This references a media file on disk and links it to this node. Additionally it
extracts matroska metadata aswell.

> [!NOTE] 
> If `path` is a directory, then these options are applied recursively
> all files inside, automatically creating new nodes based on inferred IDs and
> linking them up.

### Example

```yaml
id: decay-2012
sources:
- !media
  path: /movies/decay.webm
  ignore_metadata: true
  ignore_attachments: false
  ignore_chapters: false
```

## `trakt`

The recommended provider for any movie, show or season. It automatically queries
other linked APIs.

### Example

```yaml
id: decay-2012
sources:
- !trakt
  kind: movie
  id: 98052
```

## `tmdb`

Just like `trakt` but uses only TMDB instead.

## `federated`

Recursively federates a node with the same ID from another instance. Requires valid credentials in the seecrets file. 

```yaml
id: movies
sources:
- !federated
  host: jellything.example.org
```
